/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.util;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import org.netbeans.api.progress.ProgressHandle;

/**
 * Small class used to update a ProgressHandle by listening to property changes.
 * Simply pass a ProressHandle, property name that indicates a change in
 * progress and a property name that indicates a finished state.
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
public class ProgressListener implements PropertyChangeListener {

    private ProgressHandle handle;
    private String progressPropertyName;
    private String finishPropertyName;

    public ProgressListener(ProgressHandle handle, String progressPropertyName, String finishPropertyName) {
        this.handle = handle;
        this.progressPropertyName = progressPropertyName;
        this.finishPropertyName = finishPropertyName;
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        if (progressPropertyName.equalsIgnoreCase(evt.getPropertyName())) {
            handle.progress((Integer) evt.getNewValue());
        } else if (finishPropertyName.equalsIgnoreCase(evt.getPropertyName())) {
            handle.finish();
        }
    }
}
