/*
 * Copyright (c) 2012 AgroSense.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    AgroSense - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.client.util;

/**
 * Unit of measure.
 * 
 * @author johan
 */
public enum UOM {
    NOT_SPECIFIED(Dimension.NOT_SPECIFIED, "Not specified"),
    AMOUNT_PER_M2(Dimension.AMOUNT_PER_AREA, "1/m2"),
    /**
     * 1/second - Amount per time unit
     */
    AMOUNT_PER_SECOND(Dimension.AMOUNT_PER_TIME, "1/s"),
    /**
     * Millimeter
     */
    MM(Dimension.LENGTH, "mm"),
    /**
     * Centimeter
     */
    CM(Dimension.LENGTH, "cm"),
    /**
     * square meter 
     */
    M2(Dimension.AREA, "m2"),
    
    MM3_PER_M2(Dimension.VOLUME_PER_AREA, "mm3/m2"),
    MM3_PER_M3(Dimension.VOLUME_PER_VOLUME, "mm3/m3"),
    MM3_PER_KG(Dimension.VOLUME_PER_MASS, "mm3/kg"),
    /**
     * mm3/second - Flow
     */
    MM3_PER_SECOND(Dimension.VOLUME_PER_TIME, "mm3/s"),
    L_PER_HA(Dimension.VOLUME_PER_AREA, "L/Ha"),
    
    MG_PER_M2(Dimension.MASS_PER_AREA, "mg/m2"),
    MG_PER_KG(Dimension.MASS_PER_MASS, "mg/kg"),
    /**
     * Milligram per second = Mass flow
     */
    MG_PER_SECOND(Dimension.MASS_PER_TIME, "mg/s"),
    KG_PER_HA(Dimension.MASS_PER_AREA, "kg/Ha"),
    /**
     * Kilogram
     */
    KG(Dimension.MASS,"kg"),
    
    /**
     * Second
     */
    SECOND(Dimension.TIME, "s"),
    /**
     * Milli second
     */
    MS(Dimension.TIME, "ms")
    ;
    
    private Dimension dimension;
    private String label;

    private UOM(Dimension dimension, String label) {
        this.dimension = dimension;
        this.label = label;
    }

    public Dimension getDimension() {
        return dimension;
    }

    public String getLabel() {
        return label;
    }

    @Override
    public String toString() {
        return label;
    }
    
    
    
    // UOMs with the same dimension can be converted from one to the other.
    // TODO (low prio): set up conversion factor lookup.
    public enum Dimension {
        NOT_SPECIFIED,
        AMOUNT_PER_AREA,
        AMOUNT_PER_TIME,
        LENGTH,
        MASS,
        AREA,
        TIME,
        MASS_PER_AREA,
        MASS_PER_MASS,
        MASS_PER_TIME,
        VOLUME_PER_AREA,
        VOLUME_PER_VOLUME,
        VOLUME_PER_MASS,
        VOLUME_PER_TIME
        ;
    }
}
