/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.util.annotationhandlers;

import java.io.IOException;
import java.io.OutputStream;
import java.util.HashMap;
import java.util.Map;
import java.util.Random;
import javax.lang.model.element.Element;
import javax.lang.model.element.TypeElement;
import javax.lang.model.type.TypeKind;
import javax.lang.model.type.TypeMirror;
import nl.cloudfarming.client.util.annotations.ASIdentifying;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Gerben Feenstra
 */
@ServiceProvider(service = AnnotationHandler.class)
public class ASHashcodeHandler implements AnnotationHandler {

    private static final int[] PRIME_NUMBERS = {3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97};
    private Map<TypeElement, Integer> primesForClasses = new HashMap<TypeElement, Integer>();

    @Override
    public boolean canHandle(Class annotationClass) {
        return ASIdentifying.class.isAssignableFrom(annotationClass);
    }     
            
    @Override
    public void handle(OutputStream out, Element element) throws IOException{
        String name = AnnotationUtils.capitalize(element.getSimpleName().toString());
        TypeElement clazz = (TypeElement) element.getEnclosingElement();
        
        TypeMirror type = element.asType();
        TypeKind kind = type.getKind();
        if(kind.isPrimitive()){                                                
            out.write(("       hash = " + getHashSeed(clazz) + " * hash + this." + name + ";\n").getBytes());                        
        }
        else{
            out.write(("       hash = " + getHashSeed(clazz) + " * hash + (this." + name + " != null ? this." + name + ".hashCode() : 0);\n").getBytes());                  
        } 
    }
    
    /**
     * Get hashSeed for specified class
     * @param clazz
     * @return 
     */
    private int getHashSeed(TypeElement clazz){
        Integer storedPrime = primesForClasses.get(clazz);
        if(storedPrime == null){
            Random generator = new Random( 19580427 );
            int random = generator.nextInt(PRIME_NUMBERS.length-1);
            primesForClasses.put(clazz, random);
            storedPrime = random;
        }
        return storedPrime;
    }


}
